<?php $TRANSLATIONS = array(
"Music" => "Hudba",
"songs" => "skladby",
"albums" => "albumy",
"Add album to playlist" => "Pridať album do playlistu",
"Play" => "Prehrať",
"Pause" => "Pauza",
"Previous" => "Predchádzajúce",
"Next" => "Ďalšie",
"Mute" => "Stlmiť",
"Unmute" => "Nahlas",
"Rescan Collection" => "Znovu skenovať zbierku",
"Artist" => "Umelec",
"Album" => "Album",
"Title" => "Názov"
);
